@@ -21,12 +21,12 @@ def get_ip_adr():
 class ParamIPv4(Param):
     name = 'IPv4 adr'
 
-    def verify(self):
+    def verify(self, value):
         try:
-            adr = ip_address(self.value)
+            adr = ip_address(value)
             if not isinstance(adr, IPv4Address):
                 raise ValueError
             return adr
         except ValueError:
-            raise ValidationError(f'{self.value} is not IPv4')
+            raise ValidationError(f'{value} is not IPv4')
 
